@@ -5,7 +5,7 @@ package MooseX::YAML;
 use strict;
 use warnings;
 
-our $VERSION = "0.04_001";
+our $VERSION = "0.01";
 
 use Carp qw(croak);
 
@@ -33,27 +33,15 @@ sub _resolve {
 	if ( keys %$flags ) {
 		croak "Can't use more than one of -xs, -syck or -pp" if keys %$flags > 1;
 
-		if ( exists $flags->{-xs} ) {
+		if ( $flags->{-xs} ) {
 			require YAML::XS;
-			my $sub = YAML::XS->can($routine);
-			return sub {
-				local $YAML::XS::LoadBlessed = 1;
-				$sub->(@_);
-			};
-		} elsif ( exists $flags->{-syck} ) {
+			return YAML::XS->can($routine);
+		} elsif ( $flags->{-syck} ) {
 			require YAML::Syck;
-			my $sub = YAML::Syck->can($routine);
-			return sub {
-				local $YAML::Syck::LoadBlessed = 1;
-				$sub->(@_);
-			};
+			return YAML::Syck->can($routine);
 		} else {
 			require YAML;
-			my $sub = YAML->can($routine);
-			return sub {
-				local $YAML::LoadBlessed = 1;
-				$sub->(@_);
-			};
+			return YAML->can($routine);
 		}
 	} else {
 		my $drv = (
@@ -62,27 +50,10 @@ sub _resolve {
 			require YAML && "YAML"
 		);
 		
-		my $sub = $drv->can($routine) || croak "Can't find a provided for $routine (fallback is $drv)";
-		return sub {
-			local $YAML::LoadBlessed = 1;
-			local $YAML::XS::LoadBlessed = 1;
-			$sub->(@_);
-		};
+		return $drv->can($routine) || croak "Can't find a provided for $routine (fallback is $drv)";
 	}
 }
 
-my $load;
-sub Load {
-    $load ||= __PACKAGE__->_resolve("Load");
-    fixup( $load->(@_) );
-}
-
-my $loadfile;
-sub LoadFile {
-    $loadfile ||= __PACKAGE__->_resolve("LoadFile");
-    fixup( $loadfile->(@_) );
-}
-
 __PACKAGE__
 
 __END__
